@@ -17,7 +17,7 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *  
-* You should have received a copy of the GNU Lesser General Public 
+* You should have received a copy of the GNU Affero General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */
@@ -26,20 +26,26 @@
 OCP\JSON::checkLoggedIn();
 OCP\JSON::checkAppEnabled('bookmarks');
 
+$req_type= isset($_GET['type']) ? $_GET['type'] : 'bookmark';
 
-//Filter for tag?
-$filterTag = isset($_POST['tag']) ? htmlspecialchars_decode($_POST['tag']) : false;
+if($req_type == 'rel_tags') {
+	$tags = OC_Bookmarks_Bookmarks::analyzeTagRequest(isset($_GET['tag']) ? $_GET['tag'] : '');
+	$qtags = OC_Bookmarks_Bookmarks::findTags($tags);
+	OCP\JSON::success(array('data' => $qtags));
 
-$offset = isset($_POST['page']) ? intval($_POST['page']) * 10 : 0;
-
-$sort = isset($_POST['sort']) ? ($_POST['sort']) : 'bookmarks_sorting_recent';
-if($sort == 'bookmarks_sorting_clicks') {
-	$sqlSortColumn = 'clickcount';
-} else {
-	$sqlSortColumn = 'id';
 }
+else { // type == bookmark
+	$filterTag = OC_Bookmarks_Bookmarks::analyzeTagRequest(isset($_GET['tag']) ? $_GET['tag'] : '');
 
+	$offset = isset($_GET['page']) ? intval($_GET['page']) * 10 : 0;
 
-$bookmarks = OC_Bookmarks_Bookmarks::findBookmarks($offset, $sqlSortColumn, $filterTag, true);
+	$sort = isset($_GET['sort']) ? ($_GET['sort']) : 'bookmarks_sorting_recent';
+	if($sort == 'bookmarks_sorting_clicks') {
+		$sqlSortColumn = 'clickcount';
+	} else {
+		$sqlSortColumn = 'lastmodified';
+	}
+	$bookmarks = OC_Bookmarks_Bookmarks::findBookmarks($offset, $sqlSortColumn, $filterTag, true);
+	OCP\JSON::success(array('data' => $bookmarks));
 
-OCP\JSON::success(array('data' => $bookmarks));
+}
