@@ -8,6 +8,25 @@
 
 Calendar={
 	Util:{
+		sendmail: function(eventId, location, description, dtstart, dtend){
+			Calendar.UI.loading(true);
+			$.post(
+			OC.filePath('calendar','ajax/event','sendmail.php'),
+			{
+				eventId:eventId,
+				location:location,
+				description:description,
+				dtstart:dtstart,
+				dtend:dtend
+			},
+			function(result){
+				if(result.status !== 'success'){
+					OC.dialogs.alert(result.data.message, 'Error sending mail');
+				}
+				Calendar.UI.loading(false);
+			}
+		);
+		},
 		dateTimeToTimestamp:function(dateString, timeString){
 			dateTuple = dateString.split('-');
 			timeTuple = timeString.split(':');
@@ -61,10 +80,47 @@ Calendar={
 				$('#to').val(movedDate);
 				$('#totime').val(movedTime);
 			}
-		}
+		},
+		getDayOfWeek:function(iDay){
+			var weekArray=['sun','mon','tue','wed','thu','fri','sat'];
+			return weekArray[iDay];
+		},
+		setTimeline : function() {
+			var curTime = new Date();
+			if (curTime.getHours() == 0 && curTime.getMinutes() <= 5)// Because I am calling this function every 5 minutes
+			{
+				// the day has changed
+				var todayElem = $(".fc-today");
+				todayElem.removeClass("fc-today");
+				todayElem.removeClass("fc-state-highlight");
+
+				todayElem.next().addClass("fc-today");
+				todayElem.next().addClass("fc-state-highlight");
+			}
+
+			var parentDiv = $(".fc-agenda-slots:visible").parent();
+			var timeline = parentDiv.children(".timeline");
+			if (timeline.length == 0) {//if timeline isn't there, add it
+				timeline = $("<hr>").addClass("timeline");
+				parentDiv.prepend(timeline);
+			}
+
+			var curCalView = $('#fullcalendar').fullCalendar("getView");
+			if (curCalView.visStart < curTime && curCalView.visEnd > curTime) {
+				timeline.show();
+			} else {
+				timeline.hide();
+			}
+
+			var curSeconds = (curTime.getHours() * 60 * 60) + (curTime.getMinutes() * 60) + curTime.getSeconds();
+			var percentOfDay = curSeconds / 86400;
+			//24 * 60 * 60 = 86400, # of seconds in a day
+			var topLoc = Math.floor(parentDiv.height() * percentOfDay);
+			var appNavigationWidth = ($(window).width() > 768) ? $('#app-navigation').width() : 0;
+			timeline.css({'left':($('.fc-today').offset().left-appNavigationWidth),'width': $('.fc-today').width(),'top':topLoc + 'px'});
+		},
 	},
 	UI:{
-		scrollcount: 0,
 		loading: function(isLoading){
 			if (isLoading){
 				$('#loading').show();
@@ -74,14 +130,17 @@ Calendar={
 		},
 		startEventDialog:function(){
 			Calendar.UI.loading(false);
-			$('.tipsy').remove();
 			$('#fullcalendar').fullCalendar('unselect');
 			Calendar.UI.lockTime();
 			$( "#from" ).datepicker({
+				minDate: null,
+				maxDate: null,
 				dateFormat : 'dd-mm-yy',
 				onSelect: function(){ Calendar.Util.adjustDate(); }
 			});
 			$( "#to" ).datepicker({
+				minDate: null,
+				maxDate: null,
 				dateFormat : 'dd-mm-yy'
 			});
 			$('#fromtime').timepicker({
@@ -105,15 +164,28 @@ Calendar={
 			$('#advanced_month').change(function(){
 				Calendar.UI.repeat('month');
 			});
+			$('#event-title').bind('keydown', function(event){
+				if (event.which == 13){
+					$('#event_form #submitNewEvent').click();
+				}
+			});
 			$( "#event" ).tabs({ selected: 0});
 			$('#event').dialog({
 				width : 500,
 				height: 600,
+				resizable: false,
+				draggable: false,
 				close : function(event, ui) {
 					$(this).dialog('destroy').remove();
 				}
 			});
 			Calendar.UI.Share.init();
+			$('#sendemailbutton').click(function() {
+				Calendar.Util.sendmail($(this).attr('data-eventid'), $(this).attr('data-location'), $(this).attr('data-description'), $(this).attr('data-dtstart'), $(this).attr('data-dtend'));
+			});
+			// Focus the title, and reset the text value so that it isn't selected.
+			var val = $('#event-title').val();
+			$('#event-title').focus().val('').val(val);
 		},
 		newEvent:function(start, end, allday){
 			start = Math.round(start.getTime()/1000);
@@ -142,10 +214,10 @@ Calendar={
 			}
 		},
 		submitDeleteEventForm:function(url){
-			var post = $( '#event_form' ).serialize();
+			var id = $('input[name="id"]').val();
 			$('#errorbox').empty();
 			Calendar.UI.loading(true);
-			$.post(url, post, function(data){
+			$.post(url, {id:id}, function(data){
 					Calendar.UI.loading(false);
 					if(data.status == 'success'){
 						$('#fullcalendar').fullCalendar('removeEvents', $('#event_form input[name=id]').val());
@@ -177,6 +249,9 @@ Calendar={
 						if(data.fromtime == "true"){
 							output = output + missing_field_fromtime + "<br />";
 						}
+						if(data.interval == "true"){
+							output = output + missing_field_interval + "<br />";
+						}
 						if(data.to == "true"){
 							output = output + missing_field_todate + "<br />";
 						}
@@ -198,7 +273,10 @@ Calendar={
 				},"json");
 		},
 		moveEvent:function(event, dayDelta, minuteDelta, allDay, revertFunc){
-			$('.tipsy').remove();
+			if($('#event').length != 0) {
+				revertFunc();
+				return;
+			}
 			Calendar.UI.loading(true);
 			$.post(OC.filePath('calendar', 'ajax/event', 'move.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, allDay: allDay?1:0, lastmodified: event.lastmodified},
 			function(data) {
@@ -213,7 +291,6 @@ Calendar={
 			});
 		},
 		resizeEvent:function(event, dayDelta, minuteDelta, revertFunc){
-			$('.tipsy').remove();
 			Calendar.UI.loading(true);
 			$.post(OC.filePath('calendar', 'ajax/event', 'resize.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, lastmodified: event.lastmodified},
 			function(data) {
@@ -267,88 +344,54 @@ Calendar={
 			}
 		},
 		showCalDAVUrl:function(username, calname){
-			$('#caldav_url').val(totalurl + '/' + username + '/' + calname);
+			$('#caldav_url').val(totalurl + '/' + encodeURIComponent(username) + '/' + calname);
 			$('#caldav_url').show();
 			$("#caldav_url_close").show();
 		},
-		initScroll:function(){
-			if(window.addEventListener)
-				document.addEventListener('DOMMouseScroll', Calendar.UI.scrollCalendar, false);
-			//}else{
-				document.onmousewheel = Calendar.UI.scrollCalendar;
-			//}
-		},
-		scrollCalendar:function(event){
-			$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height() - 15);
-			$('.tipsy').remove();
-			var direction;
-			if(event.detail){
-				if(event.detail < 0){
-					direction = 'top';
-				}else{
-					direction = 'down';
-				}
-			}
-			if (event.wheelDelta){
-				if(event.wheelDelta > 0){
-					direction = 'top';
-				}else{
-					direction = 'down';
-				}
-			}
-			Calendar.UI.scrollcount++;
-			if(Calendar.UI.scrollcount < 5){
-				return;
-			}
-
-			var scroll = $(document).scrollTop(),
-				doc_height = $(document).height(),
-				win_height = $(window).height();
-			if(direction == 'down'/* && win_height == (doc_height - scroll)*/){
-				$('#fullcalendar').fullCalendar('next');
-				$(document).scrollTop(0);
-				event.preventDefault();
-			}else/* if (direction == 'top' && scroll == 0) */{
-				$('#fullcalendar').fullCalendar('prev');
-				$(document).scrollTop(win_height);
-				event.preventDefault();
-			}
-			Calendar.UI.scrollcount = 0;
-		},
 		repeat:function(task){
 			if(task=='init'){
+				
+				var byWeekNoTitle = $('#advanced_byweekno').attr('title');
 				$('#byweekno').multiselect({
 					header: false,
-					noneSelectedText: $('#advanced_byweekno').attr('title'),
+					noneSelectedText: byWeekNoTitle,
 					selectedList: 2,
-					minWidth:'auto'
+					minWidth : 60
 				});
+				
+				var weeklyoptionsTitle = $('#weeklyoptions').attr('title');
 				$('#weeklyoptions').multiselect({
 					header: false,
-					noneSelectedText: $('#weeklyoptions').attr('title'),
+					noneSelectedText: weeklyoptionsTitle,
 					selectedList: 2,
-					minWidth:'auto'
+					minWidth : 110
 				});
 				$('input[name="bydate"]').datepicker({
 					dateFormat : 'dd-mm-yy'
 				});
+				
+				var byyeardayTitle = $('#byyearday').attr('title');
 				$('#byyearday').multiselect({
 					header: false,
-					noneSelectedText: $('#byyearday').attr('title'),
+					noneSelectedText: byyeardayTitle,
 					selectedList: 2,
-					minWidth:'auto'
+					minWidth : 60
 				});
+				
+				var bymonthTitle = $('#bymonth').attr('title');
 				$('#bymonth').multiselect({
 					header: false,
-					noneSelectedText: $('#bymonth').attr('title'),
+					noneSelectedText: bymonthTitle,
 					selectedList: 2,
-					minWidth:'auto'
+					minWidth : 110
 				});
+				
+				var bymonthdayTitle = $('#bymonthday').attr('title');
 				$('#bymonthday').multiselect({
 					header: false,
-					noneSelectedText: $('#bymonthday').attr('title'),
+					noneSelectedText: bymonthdayTitle,
 					selectedList: 2,
-					minWidth:'auto'
+					minWidth : 60
 				});
 				Calendar.UI.repeat('end');
 				Calendar.UI.repeat('month');
@@ -427,17 +470,62 @@ Calendar={
 				case 'month':
 					id = 'onemonthview_radio';
 					break;
-				case 'list':
-					id = 'listview_radio';
+				case 'agendaDay':
+					id = 'onedayview_radio';
 					break;
 			}
 			$('#'+id).addClass('active');
 		},
 		categoriesChanged:function(newcategories){
-			categories = $.map(newcategories, function(v) {return v;});
+			categories = $.map(newcategories, function(v) {return v.name;});
 			console.log('Calendar categories changed to: ' + categories);
 			$('#category').multiple_autocomplete('option', 'source', categories);
 		},
+		lastView:null,
+		isToday:true,
+		timerHolder:null,
+		timerInterval:300000, // 300000 = 5*60*1000ms = 5 min
+		changeView:function(view){
+			switch (view){
+				case 'today':
+				case 'prev':
+				case 'next':
+					$('#fullcalendar').fullCalendar(view);
+					if (view=='today' && Calendar.UI.isToday) {
+						Calendar.UI.changeView('refresh')
+					}
+					if (view=='today'){
+						Calendar.UI.isToday = true;
+					}else{
+						Calendar.UI.isToday = false;
+					}
+					break;
+
+				case 'agendaDay':
+				case 'agendaWeek':
+				case 'month':
+					$('#fullcalendar').fullCalendar('changeView', view);
+					if (Calendar.UI.lastView == view) {
+						Calendar.UI.changeView('refresh')
+					}
+					Calendar.UI.lastView = view;
+					break;
+
+				case 'refresh':
+					// refetch the events.
+					$('#fullcalendar').fullCalendar('refetchEvents');
+				case 'auto_refresh':
+					// reset the timer not to refetch before new 5 min.
+					if (Calendar.UI.timerHolder){
+						window.clearTimeout(Calendar.UI.timerHolder)
+					}
+					Calendar.UI.timerHolder = window.setTimeout( function(){Calendar.UI.changeView('refresh')}, Calendar.UI.timerInterval);
+					break;
+
+				default:
+					console.error('unsupported change view to:' + view);
+			}
+		},
 		Calendar:{
 			overview:function(){
 				if($('#choosecalendar_dialog').dialog('isOpen') == true){
@@ -458,6 +546,12 @@ Calendar={
 			},
 			activation:function(checkbox, calendarid)
 			{
+				if(checkbox.checked?1:0) {
+					$('#checkbox_'+calendarid).removeClass('unchecked');
+				}
+				else {
+					$('#checkbox_'+calendarid).addClass('unchecked');
+				}
 				Calendar.UI.loading(true);
 				$.post(OC.filePath('calendar', 'ajax/calendar', 'activation.php'), { calendarid: calendarid, active: checkbox.checked?1:0 },
 				  function(data) {
@@ -472,17 +566,49 @@ Calendar={
 					}
 				  });
 			},
+			sharedEventsActivation:function(checkbox)
+			{
+				if (checkbox.checked){
+					$('#fullcalendar').fullCalendar('addEventSource', sharedEventSource);
+				}else{
+					$('#fullcalendar').fullCalendar('removeEventSource', sharedEventSource.url);
+				}
+			},
 			newCalendar:function(object){
-				var tr = $(document.createElement('tr'))
+				var div = $('<div />')
 					.load(OC.filePath('calendar', 'ajax/calendar', 'new.form.php'),
-						function(){Calendar.UI.Calendar.colorPicker(this)});
-				$(object).closest('tr').after(tr).hide();
+						function(){
+							Calendar.UI.Calendar.colorPicker(this);
+							$('#displayname_new').focus();
+						});
+				
+				var bodyListener = function(e) {
+					if($('#newcalendar_dialog').find($(e.target)).length === 0) {
+						$('#newcalendar_dialog').parent().remove();
+						$("#newCalendar").css('display', '');
+						$('body').unbind('click', bodyListener);
+					}
+				};
+				$('body').bind('click', bodyListener);
+				
+				$('#newCalendar').after(div);
+				$('#newCalendar').css('display', 'none');
 			},
 			edit:function(object, calendarid){
-				var tr = $(document.createElement('tr'))
+				var li = $(document.createElement('li'))
 					.load(OC.filePath('calendar', 'ajax/calendar', 'edit.form.php'), {calendarid: calendarid},
 						function(){Calendar.UI.Calendar.colorPicker(this)});
-				$(object).closest('tr').after(tr).hide();
+				
+				var bodyListener = function(e) {
+					if($('#editcalendar_dialog').find($(e.target)).length === 0) {
+						$(object).closest('li').before(li).show();
+						$('#editcalendar_dialog').parent().remove();
+						$('body').unbind('click', bodyListener);
+					}
+				};
+				$('body').bind('click', bodyListener);
+				
+				$(object).closest('li').after(li).hide();
 			},
 			deleteCalendar:function(calid){
 				var check = confirm("Do you really want to delete this calendar?");
@@ -494,10 +620,8 @@ Calendar={
 						if (data.status == 'success'){
 							var url = 'ajax/events.php?calendar_id='+calid;
 							$('#fullcalendar').fullCalendar('removeEventSource', url);
-							$('#choosecalendar_dialog').dialog('destroy').remove();
-							Calendar.UI.Calendar.overview();
-							$('#calendar tr[data-id="'+calid+'"]').fadeOut(400,function(){
-								$('#calendar tr[data-id="'+calid+'"]').remove();
+							$('#navigation-list li[data-id="'+calid+'"]').fadeOut(400,function(){
+								$('#navigation-list li[data-id="'+calid+'"]').remove();
 							});
 							$('#fullcalendar').fullCalendar('refetchEvents');
 						}
@@ -506,7 +630,8 @@ Calendar={
 			},
 			submit:function(button, calendarid){
 				var displayname = $.trim($("#displayname_"+calendarid).val());
-				var active = $("#edit_active_"+calendarid+":checked").length;
+				var active = $("#active_"+calendarid).attr("checked") ? 1 : 0;
+				
 				var description = $("#description_"+calendarid).val();
 				var calendarcolor = $("#calendarcolor_"+calendarid).val();
 				if(displayname == ''){
@@ -525,11 +650,20 @@ Calendar={
 				$.post(url, { id: calendarid, name: displayname, active: active, description: description, color: calendarcolor },
 					function(data){
 						if(data.status == 'success'){
-							$(button).closest('tr').prev().html(data.page).show().next().remove();
-							$('#fullcalendar').fullCalendar('removeEventSource', data.eventSource.url);
-							$('#fullcalendar').fullCalendar('addEventSource', data.eventSource);
+							if(active) {
+								$('#fullcalendar').fullCalendar('removeEventSource', data.eventSource.url);
+								$('#fullcalendar').fullCalendar('addEventSource', data.eventSource);
+							}
 							if (calendarid == 'new'){
-								$('#choosecalendar_dialog > table:first').append('<tr><td colspan="6"><a href="#" id="chooseCalendar"><input type="button" value="' + newcalendar + '"></a></td></tr>');
+								$('#newcalendar_dialog').parent().remove();
+								$("#newCalendar").css('display', '');
+								var li = $(document.createElement('li')).append(data.page);
+								$("#navigation-list").append(li);
+								$('#caldav_url_entry').appendTo("#navigation-list");
+							}
+							else {
+								$('#editcalendar_dialog').parent().remove();
+								$('#navigation-list li[data-id="'+calendarid+'"]').html(data.page).show();
 							}
 						}else{
 							$("#displayname_"+calendarid).css('background-color', '#FF2626');
@@ -540,7 +674,8 @@ Calendar={
 					}, 'json');
 			},
 			cancel:function(button, calendarid){
-				$(button).closest('tr').prev().show().next().remove();
+				$('#newcalendar_dialog').parent().remove();
+				$("#newCalendar").css('display', '');
 			},
 			colorPicker:function(container){
 				// based on jquery-colorpicker at jquery.webspirited.com
@@ -571,76 +706,82 @@ Calendar={
 		},
 		Share:{
 			init:function(){
-				var itemShares = [OC.Share.SHARE_TYPE_USER, OC.Share.SHARE_TYPE_GROUP];
-				$('#sharewith').autocomplete({minLength: 2, source: function(search, response) {
-					$.get(OC.filePath('core', 'ajax', 'share.php'), { fetch: 'getShareWith', search: search.term, itemShares: itemShares }, function(result) {
-						if (result.status == 'success' && result.data.length > 0) {
-							response(result.data);
+				if(typeof OC.Share !== typeof undefined){
+					var itemShares = [OC.Share.SHARE_TYPE_USER, OC.Share.SHARE_TYPE_GROUP];
+					$('#sharewith').autocomplete({minLength: 1, source: function(search, response) {
+						$.get(OC.filePath('core', 'ajax', 'share.php'), { fetch: 'getShareWith', search: search.term, itemShares: itemShares }, function(result) {
+							if (result.status == 'success' && result.data.length > 0) {
+								response(result.data);
+							}
+						});
+					},
+					focus: function(event, focused) {
+						event.preventDefault();
+					},
+					select: function(event, selected) {
+						var itemType = 'event';
+						var itemSource = $('#sharewith').data('item-source');
+						var shareType = selected.item.value.shareType;
+						var shareWith = selected.item.value.shareWith;
+						$(this).val(shareWith);
+						// Default permissions are Read and Share
+						var permissions = OC.PERMISSION_READ | OC.PERMISSION_SHARE;
+						OC.Share.share(itemType, itemSource, shareType, shareWith, permissions, function(data) {
+							var newitem = '<li data-item-type="event"'
+								+ 'data-share-with="'+shareWith+'" '
+								+ 'data-permissions="'+permissions+'" '
+								+ 'data-share-type="'+shareType+'">'
+								+ shareWith
+								+ (shareType === OC.Share.SHARE_TYPE_GROUP ? ' ('+t('core', 'group')+')' : '')
+								+ '<span class="shareactions">'
+								+ '<label><input class="update" type="checkbox" checked="checked">'+t('core', 'can edit')+'</label>'
+								+ '<label><input class="share" type="checkbox" checked="checked">'+t('core', 'can share')+'</label>'
+								+ '<img class="svg action delete" title="Unshare"src="'+ OC.imagePath('core', 'actions/delete.svg') +'"></span></li>';
+							$('.sharedby.eventlist').append(newitem);
+							$('#sharedWithNobody').remove();
+							$('#sharewith').val('');
+						});
+						return false;
+					}
+					});
+	
+					$('.shareactions > input:checkbox').change(function() {
+						var container = $(this).parents('li').first();
+						var permissions = parseInt(container.data('permissions'));
+						var itemType = container.data('item-type');
+						var shareType = container.data('share-type');
+						var itemSource = container.data('item');
+						var shareWith = container.data('share-with');
+						var permission = null;
+						if($(this).hasClass('update')) {
+							permission = OC.PERMISSION_UPDATE;
+							permission = OC.PERMISSION_DELETE;
+						} else if($(this).hasClass('share')) {
+							permission = OC.PERMISSION_SHARE;
 						}
+						// This is probably not the right way, but it works :-P
+						if($(this).is(':checked')) {
+							permissions += permission;
+						} else {
+							permissions -= permission;
+						}
+						
+						container.data('permissions',permissions);
+						
+						OC.Share.setPermissions(itemType, itemSource, shareType, shareWith, permissions);
 					});
-				},
-				focus: function(event, focused) {
-					event.preventDefault();
-				},
-				select: function(event, selected) {
-					var itemType = 'event';
-					var itemSource = $('#sharewith').data('item-source');
-					var shareType = selected.item.value.shareType;
-					var shareWith = selected.item.value.shareWith;
-					$(this).val(shareWith);
-					// Default permissions are Read and Share
-					var permissions = OC.PERMISSION_READ | OC.PERMISSION_SHARE;
-					OC.Share.share(itemType, itemSource, shareType, shareWith, permissions, function(data) {
-						var newitem = '<li data-item-type="event"'
-							+ 'data-share-with="'+shareWith+'" '
-							+ 'data-permissions="'+permissions+'" '
-							+ 'data-share-type="'+shareType+'">'+shareWith+' ('+(shareType == OC.Share.SHARE_TYPE_USER ? t('core', 'user') : t('core', 'group'))+')'
-							+ '<span class="shareactions"><input class="update" type="checkbox" title="'+t('core', 'Editable')+'">'
-							+ '<input class="share" type="checkbox" title="'+t('core', 'Shareable')+'" checked="checked">'
-							+ '<input class="delete" type="checkbox" title="'+t('core', 'Deletable')+'">'
-							+ '<img class="svg action delete" title="Unshare"src="'+ OC.imagePath('core', 'actions/delete.svg') +'"></span></li>';
-						$('.sharedby.eventlist').append(newitem);
-						$('#sharedWithNobody').remove();
-						$('#sharewith').val('');
+	
+					$('.shareactions > .delete').click(function() {
+						var container = $(this).parents('li').first();
+						var itemType = container.data('item-type');
+						var shareType = container.data('share-type');
+						var itemSource = container.data('item');
+						var shareWith = container.data('share-with');
+						OC.Share.unshare(itemType, itemSource, shareType, shareWith, function() {
+							container.remove();
+						});
 					});
-					return false;
 				}
-				});
-
-				$('.shareactions > input:checkbox').change(function() {
-					var container = $(this).parents('li').first();
-					var permissions = parseInt(container.data('permissions'));
-					var itemType = container.data('item-type');
-					var shareType = container.data('share-type');
-					var itemSource = container.data('item');
-					var shareWith = container.data('share-with');
-					var permission = null;
-					if($(this).hasClass('update')) {
-						permission = OC.PERMISSION_UPDATE;
-					} else if($(this).hasClass('share')) {
-						permission = OC.PERMISSION_SHARE;
-					} else if($(this).hasClass('delete')) {
-						permission = OC.PERMISSION_DELETE;
-					}
-					// This is probably not the right way, but it works :-P
-					if($(this).is(':checked')) {
-						permissions += permission;
-					} else {
-						permissions -= permission;
-					}
-					OC.Share.setPermissions(itemType, itemSource, shareType, shareWith, permissions);
-				});
-
-				$('.shareactions > .delete').click(function() {
-					var container = $(this).parents('li').first();
-					var itemType = container.data('item-type');
-					var shareType = container.data('share-type');
-					var itemSource = container.data('item');
-					var shareWith = container.data('share-with');
-					OC.Share.unshare(itemType, itemSource, shareType, shareWith, function() {
-						container.remove();
-					});
-				});
 			}
 		},
 		Drop:{
@@ -720,12 +861,6 @@ function ListView(element, calendar) {
 	t.setWidth=setWidth;
 	t.clearEvents=clearEvents;
 
-	function setHeight(height, dateChanged) {
-	}
-
-	function setWidth(width) {
-	}
-
 	function clearEvents() {
 		this.reportEventClear();
 	}
@@ -855,7 +990,20 @@ function ListView(element, calendar) {
 	}
 }
 $(document).ready(function(){
-	Calendar.UI.initScroll();
+	Calendar.UI.lastView = defaultView;
+	Calendar.UI.changeView('auto_refresh');
+	
+	/**
+	* Set an interval timer to make the timeline move 
+	*/
+	setInterval(Calendar.Util.setTimeline,60000);	
+	$(window).resize(_.debounce(function() {
+		/**
+		* When i use it instant the timeline is walking behind the facts
+		* A little timeout will make sure that it positions correctly
+		*/
+		setTimeout(Calendar.Util.setTimeline,500);
+	}));
 	$('#fullcalendar').fullCalendar({
 		header: false,
 		firstDay: firstDay,
@@ -873,7 +1021,7 @@ $(document).ready(function(){
 		titleFormat: {
 			month: t('calendar', 'MMMM yyyy'),
 					// September 2009
-			week: t('calendar', "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}"),
+			week: t('calendar', "MMM d[ yyyy]{ '–'[ MMM] d yyyy}"),
 					// Sep 7 - 13 2009
 			day: t('calendar', 'dddd, MMM d, yyyy'),
 					// Tuesday, Sep 8, 2009
@@ -884,12 +1032,18 @@ $(document).ready(function(){
 		dayNames: dayNames,
 		dayNamesShort: dayNamesShort,
 		allDayText: allDayText,
-		viewDisplay: function(view) {
-			$('#datecontrol_date').val($('<p>').html(view.title).text());
+		viewRender: function(view) {
+			$('#datecontrol_current').html($('<p>').html(view.title).text());
+			$( "#datecontrol_date" ).datepicker("setDate", $('#fullcalendar').fullCalendar('getDate'));
 			if (view.name != defaultView) {
 				$.post(OC.filePath('calendar', 'ajax', 'changeview.php'), {v:view.name});
 				defaultView = view.name;
 			}
+			if(view.name === 'agendaDay') {
+				$('td.fc-state-highlight').css('background-color', '#ffffff');
+			} else{
+				$('td.fc-state-highlight').css('background-color', '#ffc');
+			}
 			Calendar.UI.setViewActive(view.name);
 			if (view.name == 'agendaWeek') {
 				$('#fullcalendar').fullCalendar('option', 'aspectRatio', 0.1);
@@ -897,6 +1051,10 @@ $(document).ready(function(){
 			else {
 				$('#fullcalendar').fullCalendar('option', 'aspectRatio', 1.35);
 			}
+			try {
+				Calendar.Util.setTimeline();
+			} catch(err) {
+			}
 		},
 		columnFormat: {
 		    week: 'ddd d. MMM'
@@ -909,17 +1067,6 @@ $(document).ready(function(){
 		eventResize: Calendar.UI.resizeEvent,
 		eventRender: function(event, element) {
 			element.find('.fc-event-title').text($("<div/>").html(escapeHTML(event.title)).text())
-			element.tipsy({
-				className: 'tipsy-event',
-				opacity: 0.9,
-				gravity:$.fn.tipsy.autoBounds(150, 's'),
-				fade:true,
-				delayIn: 400,
-				html:true,
-				title:function() {
-					return Calendar.UI.getEventPopupText(event);
-				}
-			});
 		},
 		loading: Calendar.UI.loading,
 		eventSources: eventSources
@@ -938,35 +1085,81 @@ $(document).ready(function(){
 		onSelect: function(value, inst) {
 			var date = inst.input.datepicker('getDate');
 			$('#fullcalendar').fullCalendar('gotoDate', date);
+			
+			var view = $('#fullcalendar').fullCalendar('getView');
+			if(view.name == 'agendaWeek'){
+				$("[class*='fc-col']").removeClass('activeDay');
+				daySel=Calendar.Util.getDayOfWeek(date.getDay());
+				$('td.fc-'+daySel).addClass('activeDay');
+			}
+			if (view.name == 'month') {
+					$('td.fc-day').removeClass('activeDay');
+					prettyDate = $.datepicker.formatDate( 'yy-mm-dd',date);
+					$('td[data-date=' + prettyDate + ']').addClass('activeDay');
+			}
 		}
 	});
-	fillWindow($('#content'));
-	OCCategories.changed = Calendar.UI.categoriesChanged;
-	OCCategories.app = 'calendar';
-	OCCategories.type = 'event';
+
+	$(OC.Tags).on('change', function(event, data) {
+		if(data.type === 'event') {
+			Calendar.UI.categoriesChanged(data.tags);
+		}
+	});
+
 	$('#oneweekview_radio').click(function(){
-		$('#fullcalendar').fullCalendar('changeView', 'agendaWeek');
+		Calendar.UI.changeView('agendaWeek');
 	});
 	$('#onemonthview_radio').click(function(){
-		$('#fullcalendar').fullCalendar('changeView', 'month');
+		Calendar.UI.changeView('month');
 	});
-	$('#listview_radio').click(function(){
-		$('#fullcalendar').fullCalendar('changeView', 'list');
+	$('#onedayview_radio').click(function(){
+		Calendar.UI.changeView('agendaDay');
 	});
 	$('#today_input').click(function(){
-		$('#fullcalendar').fullCalendar('today');
+		Calendar.UI.changeView('today');
 	});
 	$('#datecontrol_left').click(function(){
-		$('#fullcalendar').fullCalendar('prev');
+		Calendar.UI.changeView('prev');
+	});
+	$('#datecontrol_today').click(function(){
+		Calendar.UI.changeView('today');
 	});
 	$('#datecontrol_right').click(function(){
-		$('#fullcalendar').fullCalendar('next');
+		Calendar.UI.changeView('next');
+	});
+	$('#datecontrol_current').click(function() {
+		$('#datecontrol_date').slideToggle(500);
+	});
+	$('#datecontrol_date').hide();
+	$('#app-settings-header').on('click keydown',function(event) {
+		if(wrongKey(event)) {
+			return;
+		}
+		var bodyListener = function(e) {
+			if($('#app-settings').find($(e.target)).length === 0) {
+				$('#app-settings').switchClass('open', '');
+			}
+		};
+		if($('#app-settings').hasClass('open')) {
+			$('#app-settings').switchClass('open', '');
+			$('body').unbind('click', bodyListener);
+		} else {
+			$('#app-settings').switchClass('', 'open');
+			$('body').bind('click', bodyListener);
+		}
 	});
 	Calendar.UI.Share.init();
 	Calendar.UI.Drop.init();
-	$('#choosecalendar .generalsettings').on('click keydown', function(event) {
-		event.preventDefault();
-		OC.appSettings({appid:'calendar', loadJS:true, cache:false, scriptName:'settingswrapper.php'});
-	});
-	$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height() - 15);
+	$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height());
+	// Save the eventSource for shared events.
+	for (var i in eventSources) {
+		if (eventSources[i].url.substr(-13) === 'shared_events') {
+			sharedEventSource = eventSources[i];
+		}
+	}
 });
+
+var wrongKey = function(event) {
+	return ((event.type === 'keydown' || event.type === 'keypress') 
+		&& (event.keyCode !== 32 && event.keyCode !== 13));
+};
