@@ -4,25 +4,74 @@
 "No calendars found." => "Kalendreid ei leitud.",
 "No events found." => "Üritusi ei leitud.",
 "Wrong calendar" => "Vale kalender",
+"You do not have the permissions to edit this event." => "Sul pole õigusi selle ürituse muutmiseks.",
 "The file contained either no events or all events are already saved in your calendar." => "Failis polnud ühtegi üritust või kõik üritused on juba sinu kalendrisse salvestatud.",
-"events has been saved in the new calendar" => "üritust salvestati uude kalendrisse",
 "Import failed" => "Importimine ebaõnnestus",
-"events has been saved in your calendar" => "üritused on salvestatud sinu kalendrisse",
 "New Timezone:" => "Uus ajavöönd:",
 "Timezone changed" => "Ajavöönd on muudetud",
 "Invalid request" => "Vigane päring",
 "Calendar" => "Kalender",
-"user" => "kasutaja",
+"Deletion failed" => "Kustutamine ebaõnnestus",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
 "group" => "grupp",
-"Editable" => "Muudetav",
-"Shareable" => "Jagatav",
-"Deletable" => "Kustutatav",
+"can edit" => "saab muuta",
+"can share" => "saab jagada",
 "ddd" => "ddd",
 "ddd M/d" => "ddd M/d",
 "dddd M/d" => "dddd M/d",
 "MMMM yyyy" => "MMMM yyyy",
-"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
+"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
+"Sunday" => "Pühapäev",
+"Monday" => "Esmaspäev",
+"Tuesday" => "Teisipäev",
+"Wednesday" => "Kolmapäev",
+"Thursday" => "Neljapäev",
+"Friday" => "Reede",
+"Saturday" => "Laupäev",
+"Sun." => "P",
+"Mon." => "E",
+"Tue." => "T",
+"Wed." => "K",
+"Thu." => "N",
+"Fri." => "R",
+"Sat." => "L",
+"January" => "Jaanuar",
+"February" => "Veebruar",
+"March" => "Märts",
+"April" => "Aprill",
+"May" => "Mai",
+"June" => "Juuni",
+"July" => "Juuli",
+"August" => "August",
+"September" => "September",
+"October" => "Oktoober",
+"November" => "November",
+"December" => "Detsember",
+"Jan." => "Jaan.",
+"Feb." => "Veebr.",
+"Mar." => "Mär.",
+"Apr." => "Apr.",
+"May." => "Mai",
+"Jun." => "Jun.",
+"Jul." => "Jul.",
+"Aug." => "Aug.",
+"Sep." => "Sept.",
+"Oct." => "Okt.",
+"Nov." => "Nov.",
+"Dec." => "Dets.",
+"All day" => "Kogu päev",
+"New Calendar" => "Uus kalender",
+"Missing or invalid fields" => "Puuduvad või vigased väljad",
+"Title" => "Pealkiri",
+"From Date" => "Alates kuupäevast",
+"From Time" => "Alates kellaajast",
+"To Date" => "Kuni kuupäevani",
+"To Time" => "Kuni kellaajani",
+"The event ends before it starts" => "Üritus lõpeb enne, kui see algab",
+"There was a database fail" => "Tekkis andmebaasi viga",
+"Interval is not valid. It must be a positive integer!" => "Intervall pole korrektne. See peab olema positiivne arv!",
 "Birthday" => "Sünnipäev",
 "Business" => "Äri",
 "Call" => "Helista",
@@ -43,10 +92,13 @@
 "You do not have the permissions to update this calendar." => "Sul pole õigusi selle kalendri uuendamiseks.",
 "You do not have the permissions to delete this calendar." => "Sul pole õigusi selle kalendri kustutamiseks.",
 "You do not have the permissions to add to this calendar." => "Sul pole õigusi selle kalendri lisamiseks.",
-"New Calendar" => "Uus kalender",
 "You do not have the permissions to add events to this calendar." => "Sul pole õigusi sellesse kalendrisse ürituste lisamiseks.",
-"You do not have the permissions to edit this event." => "Sul pole õigusi selle ürituse muutmiseks.",
+"You cannot add non-public events to a shared calendar." => "Sa ei saa lisada jagatud kalendrisse mitte-avalikke sündmusi.",
 "You do not have the permissions to delete this event." => "Sul pole õigusi selle ürituse kustutamiseks.",
+"Busy" => "Hõivatud",
+"Show full event" => "Näita kogu sündmust",
+"Show only busy" => "Näita ainult hõivatud",
+"Hide event" => "Peida sündmus",
 "Does not repeat" => "Ei kordu",
 "Daily" => "Iga päev",
 "Weekly" => "Iga nädal",
@@ -59,13 +111,6 @@
 "by date" => "kuupäeva järgi",
 "by monthday" => "kuu päeva järgi",
 "by weekday" => "nädalapäeva järgi",
-"Monday" => "Esmaspäev",
-"Tuesday" => "Teisipäev",
-"Wednesday" => "Kolmapäev",
-"Thursday" => "Neljapäev",
-"Friday" => "Reede",
-"Saturday" => "Laupäev",
-"Sunday" => "Pühapäev",
 "events week of month" => "ürituse kuu nädal",
 "first" => "esimene",
 "second" => "teine",
@@ -73,92 +118,52 @@
 "fourth" => "neljas",
 "fifth" => "viies",
 "last" => "viimane",
-"January" => "Jaanuar",
-"February" => "Veebruar",
-"March" => "Märts",
-"April" => "Aprill",
-"May" => "Mai",
-"June" => "Juuni",
-"July" => "Juuli",
-"August" => "August",
-"September" => "September",
-"October" => "Oktoober",
-"November" => "November",
-"December" => "Detsember",
 "by events date" => "ürituste kuupäeva järgi",
 "by yearday(s)" => "aasta päeva(de) järgi",
 "by weeknumber(s)" => "nädala numbri(te) järgi",
 "by day and month" => "kuu ja päeva järgi",
+"Contact birthdays" => "Kontakti sünnipäevad",
 "Date" => "Kuupäev",
 "Cal." => "Kal.",
-"Sun." => "P",
-"Mon." => "E",
-"Tue." => "T",
-"Wed." => "K",
-"Thu." => "N",
-"Fri." => "R",
-"Sat." => "L",
-"Jan." => "Jaan.",
-"Feb." => "Veebr.",
-"Mar." => "Mär.",
-"Apr." => "Apr.",
-"May." => "Mai",
-"Jun." => "Jun.",
-"Jul." => "Jul.",
-"Aug." => "Aug.",
-"Sep." => "Sept.",
-"Oct." => "Okt.",
-"Nov." => "Nov.",
-"Dec." => "Dets.",
-"All day" => "Kogu päev",
-"Missing fields" => "Puuduvad väljad",
-"Title" => "Pealkiri",
-"From Date" => "Alates kuupäevast",
-"From Time" => "Alates kellaajast",
-"To Date" => "Kuni kuupäevani",
-"To Time" => "Kuni kellaajani",
-"The event ends before it starts" => "Üritus lõpeb enne, kui see algab",
-"There was a database fail" => "Tekkis andmebaasi viga",
+"Day" => "Päev",
 "Week" => "Nädal",
 "Month" => "Kuu",
-"List" => "Nimekiri",
 "Today" => "Täna",
-"Calendars" => "Kalendrid",
-"Settings" => "Seaded",
-"Your calendars" => "Sinu kalendrid",
 "CalDav Link" => "CalDav Link",
+"Timezone" => "Ajavöönd",
+"Update timezone automatically" => "Uuenda ajavööndit automaatselt",
+"Time format" => "Ajavorming",
+"24h" => "24h",
+"12h" => "12h",
+"Start week on" => "Nädal algab päevaga",
+"Cache" => "Puhver",
+"Clear cache for repeating events" => "Tühjenda korduvate ürituste puhver",
+"Primary CalDAV address" => "Primaarne CalDAV aadress",
+"iOS/OS X CalDAV address" => "iOS/OS X CalDAV aadress",
 "Share Calendar" => "Jaga kalendrit",
 "Download" => "Lae alla",
 "Edit" => "Muuda",
 "Delete" => "Kustuta",
-"shared with you by" => "jagas sinuga",
 "New calendar" => "Uus kalender",
 "Edit calendar" => "Muuda kalendrit",
-"Displayname" => "Näidatav nimi",
-"Active" => "Aktiivne",
-"Calendar color" => "Kalendri värv",
-"Save" => "Salvesta",
-"Submit" => "OK",
-"Cancel" => "Loobu",
-"Edit an event" => "Muuda sündmust",
-"Export" => "Ekspordi",
+"Edit event" => "Muuda sündmust",
+"Save event" => "Salvesta sündmus",
+"Delete event" => "Kustuta sündmus",
 "Eventinfo" => "Ürituse info",
 "Repeating" => "Kordamine",
 "Alarm" => "Alarm",
 "Attendees" => "Osalejad",
 "Share" => "Jaga",
 "Title of the Event" => "Sündmuse pealkiri",
-"Category" => "Kategooria",
-"Separate categories with commas" => "Eralda kategooriad komadega",
-"Edit categories" => "Muuda kategooriaid",
+"from" => "alates",
+"to" => "kuni",
 "All Day Event" => "Kogu päeva sündmus",
-"From" => "Alates",
-"To" => "Kuni",
 "Advanced options" => "Lisavalikud",
 "Location" => "Asukoht",
-"Location of the Event" => "Sündmuse toimumiskoht",
+"Categories (separate by comma)" => "Kategooriad (eralda komaga)",
+"Edit categories" => "Muuda kategooriaid",
 "Description" => "Kirjeldus",
-"Description of the Event" => "Sündmuse kirjeldus",
+"Export event" => "Ekspordi sündmus",
 "Repeat" => "Korda",
 "Advanced" => "Täpsem",
 "Select weekdays" => "Vali nädalapäevad",
@@ -171,38 +176,30 @@
 "Interval" => "Intervall",
 "End" => "Lõpp",
 "occurrences" => "toimumiskordi",
+"Visibility to people shared with" => "Nähtavus jagamisel",
 "create a new calendar" => "loo uus kalender",
 "Import a calendar file" => "Impordi kalendrifail",
 "Please choose a calendar" => "Palun vali kalender",
 "Name of new calendar" => "Uue kalendri nimi",
 "Take an available name!" => "Võta saadaolev nimi!",
 "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Selle nimega kalender on juba olemas. Kui sa siiski jätkad, siis need kalendrid liidetakse.",
+"Remove all events from the selected calendar" => "Eemalda valitud kalendrist kõik sündmused",
 "Import" => "Impordi",
 "Close Dialog" => "Sulge dialoogiaken",
 "Create a new event" => "Loo sündmus",
-"Share with:" => "Jaga kasutajaga:",
-"Shared with" => "Jagatud kasutajaga",
+"Create event" => "Loo sündmus",
+"Share with user or group" => "Jaga kasutaja või grupiga",
 "Unshare" => "Lõpeta jagamine",
-"Nobody" => "Mitte keegi",
+"Not shared with anyone" => "Pole kellegagi jagatud",
+"Send Email" => "Saada e-post",
 "Shared via calendar" => "Jaga läbi kalendri",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "MÄRKUS: Läbi selle kalendri jagatud üritused mõjutavad kogu kalendri jagamist.",
+"Not shared with anyone via calendar" => "Pole kellegagi jagatud kalendri kaudu",
 "View an event" => "Vaata üritust",
+"Category" => "Kategooria",
 "No categories selected" => "Ühtegi kategooriat pole valitud",
-"of" => "/",
+"%s of %s" => "%s  %s",
+"Access Class" => "Ligipääsu klass",
+"From" => "Alates",
 "at" => "kell",
-"General" => "Üldine",
-"Timezone" => "Ajavöönd",
-"Update timezone automatically" => "Uuenda ajavööndit automaatselt",
-"Time format" => "Ajavorming",
-"24h" => "24h",
-"12h" => "12h",
-"Start week on" => "Nädal algab päevaga",
-"Cache" => "Puhver",
-"Clear cache for repeating events" => "Tühjenda korduvate ürituste puhver",
-"URLs" => "URL-id",
-"Calendar CalDAV syncing addresses" => "Kalendri CalDAV sünkroniseerimise aadressid",
-"more info" => "lisainfo",
-"Primary address (Kontact et al)" => "Peamine aadress (Kontact et al)",
-"iOS/OS X" => "iOS/OS X",
-"Read only iCalendar link(s)" => " iCalendar lingid ainult loetavana"
+"To" => "Kuni"
 );
