@@ -8,7 +8,7 @@
  *
  * This class manages our app actions
  */
-OC_Calendar_App::$l10n = new OC_L10N('calendar');
+OC_Calendar_App::$l10n = OCP\Util::getL10N('calendar');
 OC_Calendar_App::$tz = OC_Calendar_App::getTimezone();
 class OC_Calendar_App{
 	const CALENDAR = 'calendar';
@@ -42,7 +42,14 @@ class OC_Calendar_App{
 
 		$calendar = OC_Calendar_Calendar::find($id);
 		// FIXME: Correct arguments to just check for permissions
-		if($security === true || $shared === true) {
+		if($security === true && $shared === false) {
+			if(OCP\User::getUser() === $calendar['userid']){
+				return $calendar;
+			}else{
+				return false;
+			}
+		}
+		if($security === true && $shared === true) {
 			if(OCP\Share::getItemSharedWithBySource('calendar', $id)) {
 				return $calendar;
 			}
@@ -109,7 +116,7 @@ class OC_Calendar_App{
 	 * @brief returns the default categories of ownCloud
 	 * @return (array) $categories
 	 */
-	protected static function getDefaultCategories() {
+	public static function getDefaultCategories() {
 		return array(
 			(string)self::$l10n->t('Birthday'),
 			(string)self::$l10n->t('Business'),
@@ -133,11 +140,14 @@ class OC_Calendar_App{
 	 * @brief returns the vcategories object of the user
 	 * @return (object) $vcategories
 	 */
-	protected static function getVCategories() {
+	public static function getVCategories() {
 		if (is_null(self::$categories)) {
-			self::$categories = new OC_VCategories('calendar',
-				null,
-				self::getDefaultCategories());
+			$categories = \OC::$server->getTagManager()->load('event');
+			if($categories->isEmpty('event')) {
+				self::scanCategories();
+			}
+			self::$categories = \OC::$server->getTagManager()
+				->load('event', self::getDefaultCategories());
 		}
 		return self::$categories;
 	}
@@ -147,7 +157,11 @@ class OC_Calendar_App{
 	 * @return (array) $categories
 	 */
 	public static function getCategoryOptions() {
-		$categories = self::getVCategories()->categories();
+		$getNames = function($tag) {
+			return $tag['name'];
+		};
+		$categories = self::getVCategories()->getTags();
+		$categories = array_map($getNames, $categories);
 		return $categories;
 	}
 
@@ -161,18 +175,36 @@ class OC_Calendar_App{
 			if(count($calendars) > 0) {
 				$events = array();
 				foreach($calendars as $calendar) {
-					$calendar_events = OC_Calendar_Object::all($calendar['id']);
-					$events = $events + $calendar_events;
+					if($calendar['userid'] === OCP\User::getUser()) {
+						$calendar_events = OC_Calendar_Object::all($calendar['id']);
+						$events = $events + $calendar_events;
+					}
 				}
 			}
 		}
 		if(is_array($events) && count($events) > 0) {
-			$vcategories = self::getVCategories();
-			$vcategories->delete($vcategories->categories());
+			$vcategories = \OC::$server->getTagManager()->load('event');
+			$getName = function($tag) {
+				return $tag['name'];
+			};
+			$tags = array_map($getName, $vcategories->getTags());
+			$vcategories->delete($tags);
 			foreach($events as $event) {
 				$vobject = OC_VObject::parse($event['calendardata']);
 				if(!is_null($vobject)) {
-					self::loadCategoriesFromVCalendar($vobject);
+					$object = null;
+					if (isset($calendar->VEVENT)) {
+						$object = $calendar->VEVENT;
+					} else
+					if (isset($calendar->VTODO)) {
+						$object = $calendar->VTODO;
+					} else
+					if (isset($calendar->VJOURNAL)) {
+						$object = $calendar->VJOURNAL;
+					}
+					if ($object && isset($object->CATEGORIES)) {
+						$vcategories->addMultiple($object->CATEGORIES->getParts(), true, $event['id']);
+					}
 				}
 			}
 		}
@@ -180,9 +212,9 @@ class OC_Calendar_App{
 
 	/**
 	 * check VEvent for new categories.
-	 * @see OC_VCategories::loadFromVObject
+	 * @see \OCP\ITags::addMultiple()
 	 */
-	public static function loadCategoriesFromVCalendar(OC_VObject $calendar) {
+	public static function loadCategoriesFromVCalendar($id, OC_VObject $calendar) {
 		$object = null;
 		if (isset($calendar->VEVENT)) {
 			$object = $calendar->VEVENT;
@@ -193,11 +225,19 @@ class OC_Calendar_App{
 		if (isset($calendar->VJOURNAL)) {
 			$object = $calendar->VJOURNAL;
 		}
-		if ($object) {
-			self::getVCategories()->loadFromVObject($object, true);
+		if ($object && isset($object->CATEGORIES)) {
+			self::getVCategories()->addMultiple($object->CATEGORIES->getParts(), true, $id);
 		}
 	}
 
+ 	/**
+	 * @brief returns the options for the access class of an event
+	 * @return array - valid inputs for the access class of an event
+	 */
+	public static function getAccessClassOptions() {
+		return OC_Calendar_Object::getAccessClassOptions(self::$l10n);
+	}
+
 	/**
 	 * @brief returns the options for the repeat rule of an repeating event
 	 * @return array - valid inputs for the repeat rule of an repeating event
@@ -293,12 +333,11 @@ class OC_Calendar_App{
 	 * @param (int) $id - id of the calendar / event
 	 * @param (string) $type - type of the id (calendar/event)
 	 * @return (int) $permissions - CRUDS permissions
+	 * @param (string) $accessclass - access class (rfc5545, section 3.8.1.3)
 	 * @see OCP\Share
 	 */
-	public static function getPermissions($id, $type) {
-		 $permissions_all = OCP\Share::PERMISSION_CREATE
-				| OCP\Share::PERMISSION_READ | OCP\Share::PERMISSION_UPDATE
-				| OCP\Share::PERMISSION_DELETE | OCP\Share::PERMISSION_SHARE;
+	public static function getPermissions($id, $type, $accessclass = '') {
+		 $permissions_all = OCP\PERMISSION_ALL;
 
 		if($type == self::CALENDAR) {
 			$calendar = self::getCalendar($id, false, false);
@@ -326,12 +365,37 @@ class OC_Calendar_App{
 				if ($sharedEvent) {
 					$event_permissions = $sharedEvent['permissions'];
 				}
-				return max($calendar_permissions, $event_permissions);
+				if ($accessclass === 'PRIVATE') {
+					return 0;
+				} elseif ($accessclass === 'CONFIDENTIAL') {
+					return OCP\PERMISSION_READ;
+				} else {
+					return max($calendar_permissions, $event_permissions);
+				}
 			}
 		}
 		return 0;
 	}
 
+	/*
+	 * @brief Get the permissions for an access class 
+	 * @param (string) $accessclass - access class (rfc5545, section 3.8.1.3)
+	 * @return (int) $permissions - CRUDS permissions
+	 * @see OCP\Share
+	 */
+	public static function getAccessClassPermissions($accessclass = '') {
+
+		switch($accessclass) {
+			case 'CONFIDENTIAL':
+				return OCP\PERMISSION_READ;
+			case 'PUBLIC':
+			case '':
+				return (OCP\PERMISSION_READ | OCP\PERMISSION_UPDATE | OCP\PERMISSION_DELETE);
+			default:
+				return 0;
+		}
+	}
+
 	/**
 	 * @brief analyses the parameter for calendar parameter and returns the objects
 	 * @param (string) $calendarid - calendarid
@@ -343,7 +407,19 @@ class OC_Calendar_App{
 		$events = array();
 		if($calendarid == 'shared_events') {
 			$singleevents = OCP\Share::getItemsSharedWith('event', OC_Share_Backend_Event::FORMAT_EVENT);
+			$calendars = OC_Calendar_Calendar::allCalendars(OCP\USER::getUser());
 			foreach($singleevents as $singleevent) {
+				// Skip this single event if the whole calendar is already shared with the user.
+				$calendarShared = false;
+				foreach ($calendars as $calendar) {
+					if ($singleevent['calendarid'] === $calendar['id']) {
+						$calendarShared = true;
+						break;
+					}
+				}
+				if ($calendarShared === true) {
+					continue;
+				}
 				$singleevent['summary'] .= ' (' . self::$l10n->t('by') .  ' ' . OC_Calendar_Object::getowner($singleevent['id']) . ')';
 				$events[] =  $singleevent;
 			}
@@ -352,7 +428,7 @@ class OC_Calendar_App{
 				$calendar = self::getCalendar($calendarid);
 				OCP\Response::enableCaching(0);
 				OCP\Response::setETagHeader($calendar['ctag']);
-				$events = OC_Calendar_Object::allInPeriod($calendarid, $start, $end);
+				$events = OC_Calendar_Object::allInPeriod($calendarid, $start, $end, $calendar['userid'] !== OCP\User::getUser());
 			} else {
 				OCP\Util::emitHook('OC_Calendar', 'getEvents', array('calendar_id' => $calendarid, 'events' => &$events));
 			}
@@ -367,56 +443,138 @@ class OC_Calendar_App{
 	 * @param (int) $end - DateTime object of end
 	 * @return (array) $output - readable output
 	 */
-	public static function generateEventOutput($event, $start, $end) {
+	public static function generateEventOutput(array $event, $start, $end) {
 		if(!isset($event['calendardata']) && !isset($event['vevent'])) {
 			return false;
 		}
 		if(!isset($event['calendardata']) && isset($event['vevent'])) {
-			$event['calendardata'] = "BEGIN:VCALENDAR\nVERSION:2.0\nPRODID:ownCloud's Internal iCal System\n" . $event['vevent']->serialize() .  "END:VCALENDAR";
+			$event['calendardata'] = "BEGIN:VCALENDAR\nVERSION:2.0\nPRODID:ownCloud's Internal iCal System\n"
+				. $event['vevent']->serialize() .  "END:VCALENDAR";
 		}
-		$object = OC_VObject::parse($event['calendardata']);
-		$vevent = $object->VEVENT;
-		$return = array();
-		$id = $event['id'];
-		$allday = ($vevent->DTSTART->getDateType() == Sabre_VObject_Element_DateTime::DATE)?true:false;
-		$last_modified = @$vevent->__get('LAST-MODIFIED');
-		$lastmodified = ($last_modified)?$last_modified->getDateTime()->format('U'):0;
-		$staticoutput = array('id'=>(int)$event['id'],
-						'title' => ($event['summary']!=NULL || $event['summary'] != '')?$event['summary']: self::$l10n->t('unnamed'),
-						'description' => isset($vevent->DESCRIPTION)?$vevent->DESCRIPTION->value:'',
-						'lastmodified'=>$lastmodified,
-						'allDay'=>$allday);
-		if(OC_Calendar_Object::isrepeating($id) && OC_Calendar_Repeat::is_cached_inperiod($event['id'], $start, $end)) {
-			$cachedinperiod = OC_Calendar_Repeat::get_inperiod($id, $start, $end);
-			foreach($cachedinperiod as $cachedevent) {
-				$dynamicoutput = array();
-				if($allday) {
-					$start_dt = new DateTime($cachedevent['startdate'], new DateTimeZone('UTC'));
-					$end_dt = new DateTime($cachedevent['enddate'], new DateTimeZone('UTC'));
-					$dynamicoutput['start'] = $start_dt->format('Y-m-d');
-					$dynamicoutput['end'] = $end_dt->format('Y-m-d');
-				}else{
-					$start_dt = new DateTime($cachedevent['startdate'], new DateTimeZone('UTC'));
-					$end_dt = new DateTime($cachedevent['enddate'], new DateTimeZone('UTC'));
-					$start_dt->setTimezone(new DateTimeZone(self::$tz));
-					$end_dt->setTimezone(new DateTimeZone(self::$tz));
-					$dynamicoutput['start'] = $start_dt->format('Y-m-d H:i:s');
-					$dynamicoutput['end'] = $end_dt->format('Y-m-d H:i:s');
-				}
-				$return[] = array_merge($staticoutput, $dynamicoutput);
+		try{
+			$object = OC_VObject::parse($event['calendardata']);
+			if(!$object) {
+				\OCP\Util::writeLog('calendar', __METHOD__.' Error parsing event: '.print_r($event, true), \OCP\Util::DEBUG);
+				return array();
 			}
-		}else{
-			if(OC_Calendar_Object::isrepeating($id) || $event['repeating'] == 1) {
-				$object->expand($start, $end);
+	
+			$output = array();
+	
+			if($object->name === 'VEVENT') {
+				$vevent = $object;
+			} elseif(isset($object->VEVENT)) {
+				$vevent = $object->VEVENT;
+			} else {
+				\OCP\Util::writeLog('calendar', __METHOD__.' Object contains not event: '.print_r($event, true), \OCP\Util::DEBUG);
+				return $output;
 			}
-			foreach($object->getComponents() as $singleevent) {
-				if(!($singleevent instanceof Sabre_VObject_Component_VEvent)) {
-					continue;
+			$id = $event['id'];
+			if(OC_Calendar_Object::getowner($id) !== OCP\USER::getUser()) {
+				// do not show events with private or unknown access class
+				if (isset($vevent->CLASS)
+					&& ($vevent->CLASS->value === 'PRIVATE'
+					|| $vevent->CLASS->value === ''))
+				{
+					return $output;
 				}
-				$dynamicoutput = OC_Calendar_Object::generateStartEndDate($singleevent->DTSTART, OC_Calendar_Object::getDTEndFromVEvent($singleevent), $allday, self::$tz);
-				$return[] = array_merge($staticoutput, $dynamicoutput);
+				$object = OC_Calendar_Object::cleanByAccessClass($id, $object);
+			}
+			$allday = ($vevent->DTSTART->getDateType() == Sabre\VObject\Property\DateTime::DATE)?true:false;
+			$last_modified = @$vevent->__get('LAST-MODIFIED');
+			$lastmodified = ($last_modified)?$last_modified->getDateTime()->format('U'):0;
+			$staticoutput = array('id'=>(int)$event['id'],
+							'title' => (!is_null($vevent->SUMMARY) && $vevent->SUMMARY->value != '')? strtr($vevent->SUMMARY->value, array('\,' => ',', '\;' => ';')) : self::$l10n->t('unnamed'),
+							'description' => isset($vevent->DESCRIPTION)?strtr($vevent->DESCRIPTION->value, array('\,' => ',', '\;' => ';')):'',
+							'lastmodified'=>$lastmodified,
+							'allDay'=>$allday);
+			if(OC_Calendar_Object::isrepeating($id) && OC_Calendar_Repeat::is_cached_inperiod($event['id'], $start, $end)) {
+				$cachedinperiod = OC_Calendar_Repeat::get_inperiod($id, $start, $end);
+				foreach($cachedinperiod as $cachedevent) {
+					$dynamicoutput = array();
+					if($allday) {
+						$start_dt = new DateTime($cachedevent['startdate'], new DateTimeZone('UTC'));
+						$end_dt = new DateTime($cachedevent['enddate'], new DateTimeZone('UTC'));
+						$dynamicoutput['start'] = $start_dt->format('Y-m-d');
+						$dynamicoutput['end'] = $end_dt->format('Y-m-d');
+					}else{
+						$start_dt = new DateTime($cachedevent['startdate'], new DateTimeZone('UTC'));
+						$end_dt = new DateTime($cachedevent['enddate'], new DateTimeZone('UTC'));
+						$start_dt->setTimezone(new DateTimeZone(self::$tz));
+						$end_dt->setTimezone(new DateTimeZone(self::$tz));
+						$dynamicoutput['start'] = $start_dt->format('Y-m-d H:i:s');
+						$dynamicoutput['end'] = $end_dt->format('Y-m-d H:i:s');
+					}
+					$output[] = array_merge($staticoutput, $dynamicoutput);
+				}
+			}else{
+				if(OC_Calendar_Object::isrepeating($id) || $event['repeating'] == 1) {
+					$object->expand($start, $end);
+				}
+				foreach($object->getComponents() as $singleevent) {
+					if(!($singleevent instanceof Sabre\VObject\Component\VEvent)) {
+						continue;
+					}
+					$dynamicoutput = OC_Calendar_Object::generateStartEndDate($singleevent->DTSTART, OC_Calendar_Object::getDTEndFromVEvent($singleevent), $allday, self::$tz);
+					$output[] = array_merge($staticoutput, $dynamicoutput);
+				}
+			}
+			return $output;
+		}catch(Exception $e) {
+			$uid = 'unknown';
+			if(isset($event['uri'])){
+				$uid = $event['uri'];
+			}
+			\OCP\Util::writeLog('calendar', 'Event (' . $uid . ') contains invalid data: ' . $e->getMessage(),\OCP\Util::WARN);
+		}
+	}
+	
+	/**
+	 * @brief use to create HTML emails and send them
+	 * @param $eventid The event id
+	 * @param $location The location
+	 * @param $description The description
+	 * @param $dtstart The start date
+	 * @param $dtend The end date
+	 *
+	 */
+	public static function sendEmails($eventid, $summary, $location, $description, $dtstart, $dtend) {
+		$user = \OCP\User::getUser();
+		$eventsharees = array();
+		$eventShareesNames = array();
+		$emails = array();
+		$sharedwithByEvent = \OCP\Share::getItemShared('event', $eventid);
+		if (is_array($sharedwithByEvent)) {
+			foreach ($sharedwithByEvent as $share) {
+				if ($share['share_type'] === \OCP\Share::SHARE_TYPE_USER || $share['share_type'] === \OCP\Share::SHARE_TYPE_GROUP) {
+					$eventsharees[] = $share;
+				}
+			}
+			foreach ($eventsharees as $sharee) {
+				$eventShareesNames[] = $sharee['share_with'];
 			}
 		}
-		return $return;
+		foreach ($eventShareesNames as $name) {
+			$result = OC_Calendar_Calendar::getUsersEmails($name);
+			$emails[] = $result;
+		}
+		$adminmail = \OCP\Util::getDefaultEmailAddress('no-reply');
+		foreach ($emails as $email) {
+			if($email === null) {
+				continue;
+			}
+
+			$subject = 'Calendar Event Shared';
+
+			$message  = '<html><body>';
+			$message .= '<table style="border:1px solid black;" cellpadding="10">';
+			$message .= "<tr style='background: #eee;'><td colspan='2'><strong>" . $user . '</strong><strong> has shared with you an event</strong></td></tr>';
+			$message .= '<tr><td><strong>Summary:</strong> </td><td>' . \OCP\Util::sanitizeHTML($summary) . '</td></tr>';
+			$message .= '<tr><td><strong>Location:</strong> </td><td>' . \OCP\Util::sanitizeHTML($location) . '</td></tr>';
+			$message .= '<tr><td><strong>Description:</strong> </td><td>' . \OCP\Util::sanitizeHTML($description) . '</td></tr>';
+			$message .= '</table>';
+			$message .= '</body></html>';
+
+			OCP\Util::sendMail($email, \OCP\User::getDisplayName(), $subject, $message, $adminmail, $user, $html=1);
+		}
 	}
 }
