@@ -35,12 +35,11 @@ class FTP extends \OC\Files\Storage\StreamWrapper{
 			if ( ! $this->root || $this->root[0]!='/') {
 				$this->root='/'.$this->root;
 			}
-			//create the root folder if necessary
-			if ( ! $this->is_dir('')) {
-				$this->mkdir('');
+			if (substr($this->root, -1) !== '/') {
+				$this->root .= '/';
 			}
 		} else {
-			throw new \Exception();
+			throw new \Exception('Creating \OC\Files\Storage\FTP storage failed');
 		}
 		
 	}
@@ -62,8 +61,23 @@ class FTP extends \OC\Files\Storage\StreamWrapper{
 		$url.='://'.$this->user.':'.$this->password.'@'.$this->host.$this->root.$path;
 		return $url;
 	}
+
+	/**
+	 * Unlinks file or directory
+	 * @param string $path
+	 */
+	public function unlink($path) {
+		if ($this->is_dir($path)) {
+			return $this->rmdir($path);
+		}
+		else {
+			$url = $this->constructUrl($path);
+			$result = unlink($url);
+			clearstatcache(true, $url);
+			return $result;
+		}
+	}
 	public function fopen($path,$mode) {
-		$this->init();
 		switch($mode) {
 			case 'r':
 			case 'rb':
@@ -100,10 +114,21 @@ class FTP extends \OC\Files\Storage\StreamWrapper{
 	}
 
 	public function writeBack($tmpFile) {
-		$this->init();
 		if (isset(self::$tempFiles[$tmpFile])) {
 			$this->uploadFile($tmpFile, self::$tempFiles[$tmpFile]);
 			unlink($tmpFile);
 		}
 	}
+
+	/**
+	 * check if php-ftp is installed
+	 */
+	public static function checkDependencies() {
+		if (function_exists('ftp_login')) {
+			return(true);
+		} else {
+			return array('ftp');
+		}
+	}
+
 }
