@@ -8,102 +8,99 @@
 
 namespace OC\Files\Storage;
 
-abstract class StreamWrapper extends \OC\Files\Storage\Common{
-	private $ready = false;
-
-	protected function init(){
-		if($this->ready) {
-			return;
-		}
-		$this->ready = true;
-
-		//create the root folder if necesary
-		if(!$this->is_dir('')) {
-			$this->mkdir('');
-		}
-	}
+abstract class StreamWrapper extends Common {
 
+	/**
+	 * @param string $path
+	 * @return string|null
+	 */
 	abstract public function constructUrl($path);
 
 	public function mkdir($path) {
-		$this->init();
 		return mkdir($this->constructUrl($path));
 	}
 
 	public function rmdir($path) {
-		$this->init();
-		if($this->file_exists($path)) {
-			$succes = rmdir($this->constructUrl($path));
-			clearstatcache();
-			return $succes;
+		if ($this->file_exists($path)) {
+			$dh = $this->opendir($path);
+			while (($file = readdir($dh)) !== false) {
+				if ($this->is_dir($path . '/' . $file)) {
+					$this->rmdir($path . '/' . $file);
+				} else {
+					$this->unlink($path . '/' . $file);
+				}
+			}
+			$url = $this->constructUrl($path);
+			$success = rmdir($url);
+			clearstatcache(false, $url);
+			return $success;
 		} else {
 			return false;
 		}
 	}
 
 	public function opendir($path) {
-		$this->init();
 		return opendir($this->constructUrl($path));
 	}
 
 	public function filetype($path) {
-		$this->init();
-		return filetype($this->constructUrl($path));
-	}
-
-	public function isReadable($path) {
-		return true;//not properly supported
-	}
-
-	public function isUpdatable($path) {
-		return true;//not properly supported
+		return @filetype($this->constructUrl($path));
 	}
 
 	public function file_exists($path) {
-		$this->init();
 		return file_exists($this->constructUrl($path));
 	}
 
 	public function unlink($path) {
-		$this->init();
-		$succes = unlink($this->constructUrl($path));
-		clearstatcache();
-		return $succes;
+		$url = $this->constructUrl($path);
+		$success = unlink($url);
+		// normally unlink() is supposed to do this implicitly,
+		// but doing it anyway just to be sure
+		clearstatcache(false, $url);
+		return $success;
 	}
 
 	public function fopen($path, $mode) {
-		$this->init();
 		return fopen($this->constructUrl($path), $mode);
 	}
 
-	public function touch($path, $mtime=null) {
-		$this->init();
-		if(is_null($mtime)) {
-			$fh = $this->fopen($path, 'a');
-			fwrite($fh, '');
-			fclose($fh);
+	public function touch($path, $mtime = null) {
+		if ($this->file_exists($path)) {
+			if (is_null($mtime)) {
+				$fh = $this->fopen($path, 'a');
+				fwrite($fh, '');
+				fclose($fh);
+
+				return true;
+			} else {
+				return false; //not supported
+			}
 		} else {
-			return false;//not supported
+			$this->file_put_contents($path, '');
+			return true;
 		}
 	}
 
+	/**
+	 * @param string $path
+	 * @param string $target
+	 */
 	public function getFile($path, $target) {
-		$this->init();
 		return copy($this->constructUrl($path), $target);
 	}
 
+	/**
+	 * @param string $target
+	 */
 	public function uploadFile($path, $target) {
-		$this->init();
 		return copy($path, $this->constructUrl($target));
 	}
 
 	public function rename($path1, $path2) {
-		$this->init();
 		return rename($this->constructUrl($path1), $this->constructUrl($path2));
 	}
 
 	public function stat($path) {
-		$this->init();
 		return stat($this->constructUrl($path));
 	}
 
