@@ -21,7 +21,8 @@
 
 OC_JSON::checkLoggedIn();
 OCP\JSON::callCheck();
-OC_App::loadApps();
+
+$defaults = new \OCP\Defaults();
 
 if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSource'])) {
 	switch ($_POST['action']) {
@@ -30,18 +31,21 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				try {
 					$shareType = (int)$_POST['shareType'];
 					$shareWith = $_POST['shareWith'];
+					$itemSourceName = isset($_POST['itemSourceName']) ? $_POST['itemSourceName'] : null;
 					if ($shareType === OCP\Share::SHARE_TYPE_LINK && $shareWith == '') {
 						$shareWith = null;
 					}
-					
+
 					$token = OCP\Share::shareItem(
 						$_POST['itemType'],
 						$_POST['itemSource'],
 						$shareType,
 						$shareWith,
-						$_POST['permissions']
+						$_POST['permissions'],
+						$itemSourceName,
+						(!empty($_POST['expirationDate']) ? new \DateTime($_POST['expirationDate']) : null)
 					);
-					
+
 					if (is_string($token)) {
 						OC_JSON::success(array('data' => array('token' => $token)));
 					} else {
@@ -77,44 +81,88 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			break;
 		case 'setExpirationDate':
 			if (isset($_POST['date'])) {
-				$return = OCP\Share::setExpirationDate($_POST['itemType'], $_POST['itemSource'], $_POST['date']);
-				($return) ? OC_JSON::success() : OC_JSON::error();
+				try {
+					$return = OCP\Share::setExpirationDate($_POST['itemType'], $_POST['itemSource'], $_POST['date']);
+					($return) ? OC_JSON::success() : OC_JSON::error();
+				} catch (\Exception $e) {
+					OC_JSON::error(array('data' => array('message' => $e->getMessage())));
+				}
 			}
 			break;
+		case 'informRecipients':
+			$l = OC_L10N::get('core');
+			$shareType = (int) $_POST['shareType'];
+			$itemType = $_POST['itemType'];
+			$itemSource = $_POST['itemSource'];
+			$recipient = $_POST['recipient'];
+
+			if($shareType === \OCP\Share::SHARE_TYPE_USER) {
+				$recipientList[] = $recipient;
+			} elseif ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
+				$recipientList = \OC_Group::usersInGroup($recipient);
+			}
+			// don't send a mail to the user who shared the file
+			$recipientList = array_diff($recipientList, array(\OCP\User::getUser()));
+
+			$mailNotification = new OC\Share\MailNotifications();
+			$result = $mailNotification->sendInternalShareMail($recipientList, $itemSource, $itemType);
+
+			\OCP\Share::setSendMailStatus($itemType, $itemSource, $shareType, $recipient, true);
+
+			if (empty($result)) {
+				OCP\JSON::success();
+			} else {
+				OCP\JSON::error(array(
+					'data' => array(
+						'message' => $l->t("Couldn't send mail to following users: %s ",
+								implode(', ', $result)
+								)
+						)
+					));
+			}
+			break;
+		case 'informRecipientsDisabled':
+			$itemSource = $_POST['itemSource'];
+			$shareType = $_POST['shareType'];
+			$itemType = $_POST['itemType'];
+			$recipient = $_POST['recipient'];
+			\OCP\Share::setSendMailStatus($itemType, $itemSource, $shareType, $recipient, false);
+			OCP\JSON::success();
+			break;
+
 		case 'email':
 			// read post variables
-			$user = OCP\USER::getUser();
-			$displayName = OCP\User::getDisplayName();
-			$type = $_POST['itemType'];
 			$link = $_POST['link'];
 			$file = $_POST['file'];
 			$to_address = $_POST['toaddress'];
 
-			// enable l10n support
-			$l = OC_L10N::get('core');
+			$mailNotification = new \OC\Share\MailNotifications();
 
-			// setup the email
-			$subject = (string)$l->t('User %s shared a file with you', $displayName);
-			if ($type === 'dir')
-				$subject = (string)$l->t('User %s shared a folder with you', $displayName);
+			$expiration = null;
+			if (isset($_POST['expiration']) && $_POST['expiration'] !== '') {
+				try {
+					$date = new DateTime($_POST['expiration']);
+					$expiration = $date->getTimestamp();
+				} catch (Exception $e) {
+					\OCP\Util::writeLog('sharing', "Couldn't read date: " . $e->getMessage(), \OCP\Util::ERROR);
+				}
 
-			$text = (string)$l->t('User %s shared the file "%s" with you. It is available for download here: %s',
-				array($displayName, $file, $link));
-			if ($type === 'dir')
-				$text = (string)$l->t('User %s shared the folder "%s" with you. It is available for download here: %s',
-					array($displayName, $file, $link));
-
-
-			$default_from = OCP\Util::getDefaultEmailAddress('sharing-noreply');
-			$from_address = OCP\Config::getUserValue($user, 'settings', 'email', $default_from );
-
-			// send it out now
-			try {
-				OCP\Util::sendMail($to_address, $to_address, $subject, $text, $from_address, $user);
-				OCP\JSON::success();
-			} catch (Exception $exception) {
-				OCP\JSON::error(array('data' => array('message' => OC_Util::sanitizeHTML($exception->getMessage()))));
 			}
+
+			$result = $mailNotification->sendLinkShareMail($to_address, $file, $link, $expiration);
+			if(empty($result)) {
+				\OCP\JSON::success();
+			} else {
+				$l = OC_L10N::get('core');
+				OCP\JSON::error(array(
+					'data' => array(
+						'message' => $l->t("Couldn't send mail to following users: %s ",
+								implode(', ', $result)
+							)
+					)
+				));
+			}
+
 			break;
 	}
 } else if (isset($_GET['fetch'])) {
@@ -155,9 +203,37 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				OC_JSON::success(array('data' => array('reshare' => $reshare, 'shares' => $shares)));
 			}
 			break;
+		case 'getShareWithEmail':
+			$result = array();
+			if (isset($_GET['search'])) {
+				$cm = OC::$server->getContactsManager();
+				if (!is_null($cm) && $cm->isEnabled()) {
+					$contacts = $cm->search($_GET['search'], array('FN', 'EMAIL'));
+					foreach ($contacts as $contact) {
+						if (!isset($contact['EMAIL'])) {
+							continue;
+						}
+
+						$emails = $contact['EMAIL'];
+						if (!is_array($emails)) {
+							$emails = array($emails);
+						}
+
+						foreach($emails as $email) {
+							$result[] = array(
+								'id' => $contact['id'],
+								'email' => $email,
+								'displayname' => $contact['FN'],
+							);
+						}
+					}
+				}
+			}
+			OC_JSON::success(array('data' => $result));
+			break;
 		case 'getShareWith':
 			if (isset($_GET['search'])) {
-				$sharePolicy = OC_Appconfig::getValue('core', 'shareapi_share_policy', 'global');
+				$shareWithinGroupOnly = OC\Share\Share::shareWithGroupMembersOnly();
 				$shareWith = array();
 // 				if (OC_App::isEnabled('contacts')) {
 // 					// TODO Add function to contacts to only get the 'fullname' column to improve performance
@@ -176,10 +252,10 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 // 						}
 // 					}
 // 				}
-				if ($sharePolicy == 'groups_only') {
-					$groups = OC_Group::getUserGroups(OC_User::getUser());
-				} else {
-					$groups = OC_Group::getGroups();
+				$groups = OC_Group::getGroups($_GET['search']);
+				if ($shareWithinGroupOnly) {
+					$usergroups = OC_Group::getUserGroups(OC_User::getUser());
+					$groups = array_intersect($groups, $usergroups);
 				}
 				$count = 0;
 				$users = array();
@@ -187,8 +263,8 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				$offset = 0;
 				while ($count < 15 && count($users) == $limit) {
 					$limit = 15 - $count;
-					if ($sharePolicy == 'groups_only') {
-						$users = OC_Group::DisplayNamesInGroups($groups, $_GET['search'], $limit, $offset);
+					if ($shareWithinGroupOnly) {
+						$users = OC_Group::DisplayNamesInGroups($usergroups, $_GET['search'], $limit, $offset);
 					} else {
 						$users = OC_User::getDisplayNames($_GET['search'], $limit, $offset);
 					}
@@ -200,23 +276,27 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 							&& $uid != OC_User::getUser()) {
 							$shareWith[] = array(
 								'label' => $displayName,
-								'value' => array('shareType' => OCP\Share::SHARE_TYPE_USER,
-								'shareWith' => $uid)
+								'value' => array(
+									'shareType' => OCP\Share::SHARE_TYPE_USER,
+									'shareWith' => $uid)
 							);
 							$count++;
 						}
 					}
 				}
 				$count = 0;
+
+				// enable l10n support
+				$l = OC_L10N::get('core');
+
 				foreach ($groups as $group) {
 					if ($count < 15) {
-						if (stripos($group, $_GET['search']) !== false
-							&& (!isset($_GET['itemShares'])
+						if (!isset($_GET['itemShares'])
 							|| !isset($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])
 							|| !is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])
-							|| !in_array($group, $_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP]))) {
+							|| !in_array($group, $_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])) {
 							$shareWith[] = array(
-								'label' => $group.' (group)',
+								'label' => $group,
 								'value' => array(
 									'shareType' => OCP\Share::SHARE_TYPE_GROUP,
 									'shareWith' => $group
@@ -228,6 +308,10 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 						break;
 					}
 				}
+				$sorter = new \OC\Share\SearchResultSorter($_GET['search'],
+														   'label',
+														   new \OC\Log());
+				usort($shareWith, array($sorter, 'sort'));
 				OC_JSON::success(array('data' => $shareWith));
 			}
 			break;
